@@ -311,6 +311,7 @@ class HarosLauncher(object):
                             help = "load/export using the given directory")
         parser.add_argument("--no-cache", action = "store_true",
                             help = "do not use available caches")
+        parser.add_argument("--ws", help = "set the catkin workspace directory")
         parser.add_argument("--no-write-cache", action = "store_true",
                             help = "do not update parsing cache")
         parser.add_argument("--junit-xml-output", action='store_true',
@@ -804,15 +805,18 @@ class HarosAnalyseRunner(HarosCommonExporter):
         parser = None
         try:
             # lazy import; this is an optional dependency
-            from .hpl.hpl_parser import UserSpecParser
+            from .hpl_parser import UserSpecParser
             parser = UserSpecParser()
-        except ImportError:
+        except ImportError as e:
             self.log.warning(("Found HPL specifications, "
                 "but the HPL parser could not be found."))
+            self.log.error(repr(e))
             return
         for config in configs:
+            self.log.debug("Parsing HPL properties for %s", config.id)
             parser.parse_config_specs(config)
         for node in nodes:
+            self.log.debug("Parsing HPL properties for %s", node.id)
             parser.parse_node_specs(node)
 
     def _analyse(self, plugins, rules, metrics):
